<!doctype html>
<html lang="zh-CN">
    <head>
        <meta charset="UTF-8">
        <title>downloader</title>
        <link href="/static/css/bootstrap.min.css" rel="stylesheet">
    </head>
    <body>
        <h1>downloader version:{{version}}</h1>
        <p>this is a downloader.You are in the web-running mode</p>
        <script src="/static/js/jquery.min.css"></script>
        <script src="/static/js/bootstrap.min.js"></script>
    </body>
</html>